==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/LDAPIdentityProviderBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class LDAPIdentityProviderBuilder extends io.fabric8.openshift.api.model.LDAPIdentityProviderFluentImpl<io.fabric8.openshift.api.model.LDAPIdentityProviderBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.LDAPIdentityProvider,io.fabric8.openshift.api.model.LDAPIdentityProviderBuilder>{
  public LDAPIdentityProviderBuilder() {
    this(false);
  }
  public LDAPIdentityProviderBuilder(java.lang.Boolean validationEnabled) {
    this(new LDAPIdentityProvider(), validationEnabled);
  }
  public LDAPIdentityProviderBuilder(io.fabric8.openshift.api.model.LDAPIdentityProviderFluent<?> fluent) {
    this(fluent, false);
  }
  public LDAPIdentityProviderBuilder(io.fabric8.openshift.api.model.LDAPIdentityProviderFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new LDAPIdentityProvider(), validationEnabled);
  }
  public LDAPIdentityProviderBuilder(io.fabric8.openshift.api.model.LDAPIdentityProviderFluent<?> fluent,io.fabric8.openshift.api.model.LDAPIdentityProvider instance) {
    this(fluent, instance, false);
  }
  public LDAPIdentityProviderBuilder(io.fabric8.openshift.api.model.LDAPIdentityProviderFluent<?> fluent,io.fabric8.openshift.api.model.LDAPIdentityProvider instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAttributes(instance.getAttributes()); 
    fluent.withBindDN(instance.getBindDN()); 
    fluent.withBindPassword(instance.getBindPassword()); 
    fluent.withCa(instance.getCa()); 
    fluent.withInsecure(instance.getInsecure()); 
    fluent.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  public LDAPIdentityProviderBuilder(io.fabric8.openshift.api.model.LDAPIdentityProvider instance) {
    this(instance,false);
  }
  public LDAPIdentityProviderBuilder(io.fabric8.openshift.api.model.LDAPIdentityProvider instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAttributes(instance.getAttributes()); 
    this.withBindDN(instance.getBindDN()); 
    this.withBindPassword(instance.getBindPassword()); 
    this.withCa(instance.getCa()); 
    this.withInsecure(instance.getInsecure()); 
    this.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.LDAPIdentityProviderFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.LDAPIdentityProvider build() {
    LDAPIdentityProvider buildable = new LDAPIdentityProvider(fluent.getAttributes(),fluent.getBindDN(),fluent.getBindPassword(),fluent.getCa(),fluent.getInsecure(),fluent.getUrl());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LDAPIdentityProviderBuilder that = (LDAPIdentityProviderBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/LDAPIdentityProviderBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class LDAPIdentityProviderBuilder extends io.fabric8.openshift.api.model.LDAPIdentityProviderFluentImpl<io.fabric8.openshift.api.model.LDAPIdentityProviderBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.LDAPIdentityProvider,io.fabric8.openshift.api.model.LDAPIdentityProviderBuilder>{
  public LDAPIdentityProviderBuilder() {
    this(false);
  }
  public LDAPIdentityProviderBuilder(java.lang.Boolean validationEnabled) {
    this(new LDAPIdentityProvider(), validationEnabled);
  }
  public LDAPIdentityProviderBuilder(io.fabric8.openshift.api.model.LDAPIdentityProviderFluent<?> fluent) {
    this(fluent, false);
  }
  public LDAPIdentityProviderBuilder(io.fabric8.openshift.api.model.LDAPIdentityProviderFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new LDAPIdentityProvider(), validationEnabled);
  }
  public LDAPIdentityProviderBuilder(io.fabric8.openshift.api.model.LDAPIdentityProviderFluent<?> fluent,io.fabric8.openshift.api.model.LDAPIdentityProvider instance) {
    this(fluent, instance, false);
  }
  public LDAPIdentityProviderBuilder(io.fabric8.openshift.api.model.LDAPIdentityProviderFluent<?> fluent,io.fabric8.openshift.api.model.LDAPIdentityProvider instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAttributes(instance.getAttributes()); 
    fluent.withBindDN(instance.getBindDN()); 
    fluent.withBindPassword(instance.getBindPassword()); 
    fluent.withCa(instance.getCa()); 
    fluent.withInsecure(instance.getInsecure()); 
    fluent.withUrl(instance.getUrl()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public LDAPIdentityProviderBuilder(io.fabric8.openshift.api.model.LDAPIdentityProvider instance) {
    this(instance,false);
  }
  public LDAPIdentityProviderBuilder(io.fabric8.openshift.api.model.LDAPIdentityProvider instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAttributes(instance.getAttributes()); 
    this.withBindDN(instance.getBindDN()); 
    this.withBindPassword(instance.getBindPassword()); 
    this.withCa(instance.getCa()); 
    this.withInsecure(instance.getInsecure()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.LDAPIdentityProviderFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.LDAPIdentityProvider build() {
    LDAPIdentityProvider buildable = new LDAPIdentityProvider(fluent.getAttributes(),fluent.getBindDN(),fluent.getBindPassword(),fluent.getCa(),fluent.getInsecure(),fluent.getUrl());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LDAPIdentityProviderBuilder that = (LDAPIdentityProviderBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
